==> haskell-word-wrap-0.4.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-word-wrap.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: word-wrap
version: 0.4.1
id: word-wrap-0.4.1-5oILE0kqGlZEeMmisi5Y34
key: word-wrap-0.4.1-5oILE0kqGlZEeMmisi5Y34
license: BSD3
copyright: 2017 Jonathan Daugherty
maintainer: cygnus@foobox.com
homepage: https://github.com/jtdaugherty/word-wrap/
synopsis: A library for word-wrapping
description:
    A library for wrapping long lines of text.
category: Text
author: Jonathan Daugherty
exposed: True
indefinite: False
exposed-modules:
    Text.Wrap
abi: 63d0e193a6920470c4baf7f64fdc3d7a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/word-wrap-0.4.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/word-wrap-0.4.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/word-wrap-0.4.1
hs-libraries: HSword-wrap-0.4.1-5oILE0kqGlZEeMmisi5Y34
depends:
    base-4.10.1.0 text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
haddock-interfaces: /usr/share/doc/haskell-word-wrap/html/word-wrap.haddock
haddock-html: /usr/share/doc/haskell-word-wrap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-word-wrap-0.4.1-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-word-wrap.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: word-wrap
version: 0.4.1
id: word-wrap-0.4.1-8q7IBfeWKCYpp0REsea6H
key: word-wrap-0.4.1-8q7IBfeWKCYpp0REsea6H
license: BSD3
copyright: 2017 Jonathan Daugherty
maintainer: cygnus@foobox.com
homepage: https://github.com/jtdaugherty/word-wrap/
synopsis: A library for word-wrapping
description:
    A library for wrapping long lines of text.
category: Text
author: Jonathan Daugherty
exposed: True
indefinite: False
exposed-modules:
    Text.Wrap
abi: 9247c943d1eef469de3b1be634a18d17
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/word-wrap-0.4.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/word-wrap-0.4.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/word-wrap-0.4.1
hs-libraries: HSword-wrap-0.4.1-8q7IBfeWKCYpp0REsea6H
depends:
    base-4.10.1.0 text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
haddock-interfaces: /usr/share/doc/haskell-word-wrap/html/word-wrap.haddock
haddock-html: /usr/share/doc/haskell-word-wrap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
